==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Sukurti skaičiuoklę</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Sukurti naują skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Lygiuoti apačioje</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas apačioje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas per vidurį</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Lygiavimas kairėje</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas kairėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Lygiuoti dešinėje</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas dešinėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Lygiuoti viršuje</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas viršuje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Statmenasis lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Eksportuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Eksportuoti skaičiuoklę į CSV failą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importuoti CSV failą į skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Sulieti langelius</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Sulieti pažymėtus langelius skaičiuoklėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Nustatyti kitą vardą</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Nustatyti kitą pažymėto langelio vardą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Skelti langelį</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Perskirti anksčiau sulietus langelius skaičiuoklėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Paryškintasis tekstas</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Nustatyti paryškintąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Pasvirasis tekstas</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Nustatyti pasvirąjį tekstą pažymėtuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Pabrauktasis tekstas</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Langelio savybės</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Spalva</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekstas</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fonas</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Lygiavimas</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Kairė</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Vidurys</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dešinys</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Iš viršaus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Apačioje</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stilius</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Paryškintas</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Pasvirasis</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Pabrauktas</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Ekrano vienetai</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Vienetų eilutė</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lternatyvus vardas</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Šio langelio kitas vardas</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Visi (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importuoti failą</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Eksportuoti failą</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Langelio turinys</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Rodyti skaičiuoklę</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Juoda</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Balta</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Raudona</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Tamsiai raudona</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Žalia</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Tamsiai žalia</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Mėlyna</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Tamsiai mėlyna</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Žydra</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Tamsi žalsvai mėlyna</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Rausvai raudona</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Tamsiai rausvai raudona</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Geltona</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Tamsiai geltona</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Pilka</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Tamsiai pilka</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Šviesiai pilka</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Pasirinktinė</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Turinys</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Be pavadinimo</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Įterpti eilutes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Šalinti eilutes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Įterpti stulpelius</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Šalinti stulpelius</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Savybės...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Sukurti skaičiuoklę</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Sukurti naują skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Lygiuoti apačioje</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas apačioje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas per vidurį</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Lygiavimas kairėje</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas kairėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Lygiuoti dešinėje</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas dešinėje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Lygiuoti viršuje</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas viršuje</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Statmenasis lygiavimas per vidurį</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Pasirinktų langelių turinio lygiavimas aukštyn per vidurį</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Eksportuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Eksportuoti skaičiuoklę į CSV failą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importuoti skaičiuoklę</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importuoti CSV failą į skaičiuoklę</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Sulieti langelius</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Sulieti pasirinktus langelius</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Nustatyti kitą vardą</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Nustatyti kitą pažymėto langelio vardą</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Skelti langelį</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Išskaidyti anksčiau sulietus langelius</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Paryškintasis tekstas</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Paryškinti tekstą pasirinktuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Pasvirasis tekstas</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Padaryti pasvirą tekstą pasirinktuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Pabrauktasis tekstas</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Pabraukti tekstą pasirinktuose langeliuose</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Tinkinta spalva</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Sulieti langelius</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Skelti langelį</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Įterpti eilutes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Šalinti eilutes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Įterpti stulpelius</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Langelio savybės</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Spalva</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Tekstas</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fonas</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Lygiavimas</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Gulščiai</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Iš kairės</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Vidurys</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Iš dešinės</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Stačiai</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Iš viršaus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Iš apačios</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Stilius</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Paryškintas</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Pasvirasis</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Pabrauktas</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Ekrano vienetai</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Vienetų eilutė</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lternatyvus vardas</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Šio langelio kitas vardas</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Visi (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importuoti failą</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Eksportuoti failą</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Rodyti skaičiuoklę</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Nustatyti langelio(-ų) priekinio plano spalvą</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Nustatyti lentelės langelio(-ų) priekinio plano spalvą</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Nustatyti langelio(-ų) pagrindo spalvą</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Nustatyti lentelės langelio(-ų) pagrindo spalvą</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation>Skaičiuoklė nepalaiko kelių langelių pasirinkimo įdedant.
Prašome pasirinkti tik vieną langelį.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation>Kopijavimas ir įdėjimas nepavyko</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation type="unfinished">Alias contains invalid characters!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Juoda</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Balta</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Raudona</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Tamsiai raudona</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Žalia</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Tamsiai žalia</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Mėlyna</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Tamsiai mėlyna</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Žydra</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Tamsi žalsvai mėlyna</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Rausvai raudona</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Tamsiai rausvai raudona</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Geltona</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Tamsiai geltona</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Pilka</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Tamsiai pilka</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Šviesiai pilka</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Tinkinta spalva</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation type="unfinished">&amp;Content:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation type="unfinished">&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Be pavadinimo</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Įterpti eilutes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Šalinti eilutes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Įterpti stulpelius</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Šalinti stulpelius</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Savybės...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Skaičiuoklė</translation>
    </message>
  </context>
</TS>
